==> harp-0.2.10.tar.gz: harp-0.2.10/pkg/sdk/types/string_array.go <==
// Licensed to Elasticsearch B.V. under one or more contributor
// license agreements. See the NOTICE file distributed with
// this work for additional information regarding copyright
// ownership. Elasticsearch B.V. licenses this file to you under
// the Apache License, Version 2.0 (the "License"); you may
// not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

package types

import "strings"

// StringArray describes string array type
type StringArray []string

// -----------------------------------------------------------------------------

// Contains checks if item is in collection
func (s StringArray) Contains(item string) bool {
	for _, v := range s {
		if strings.EqualFold(item, v) {
			return true
		}
	}

	return false
}

// AddIfNotContains add item if not already in collection.
// Function returns true or false according to add result.
func (s *StringArray) AddIfNotContains(item string) bool {
	if s.Contains(item) {
		// Item not added
		return false
	}
	*s = append(*s, item)

	// Item added
	return true
}

// Remove item from collection.
// Function returns true or false according to removal result.
func (s *StringArray) Remove(item string) bool {
	idx := -1
	for i, v := range *s {
		if strings.EqualFold(item, v) {
			idx = i
			break
		}
	}
	if idx < 0 {
		// Item not removed
		return false
	}
	*s = append((*s)[:idx], (*s)[idx+1:]...)

	// Item removed
	return true
}

// HasOneOf returns true when one of provided items is found in array.
func (s *StringArray) HasOneOf(items ...string) bool {
	for _, item := range items {
		if s.Contains(item) {
			return true
		}
	}

	return false
}

==> harp-0.2.11.tar.gz: harp-0.2.11/pkg/sdk/types/string_array.go <==
// Licensed to Elasticsearch B.V. under one or more contributor
// license agreements. See the NOTICE file distributed with
// this work for additional information regarding copyright
// ownership. Elasticsearch B.V. licenses this file to you under
// the Apache License, Version 2.0 (the "License"); you may
// not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

package types

import "strings"

// StringArray describes string array type
type StringArray []string

// -----------------------------------------------------------------------------

// ContainsString checks if a strings is in in StringArray
func (s StringArray) ContainsString(item string) bool {
	for _, v := range s {
		if strings.Contains(item, v) {
			return true
		}
	}

	return false
}

// Contains checks if item is in collection
func (s StringArray) Contains(item string) bool {
	for _, v := range s {
		if strings.EqualFold(item, v) {
			return true
		}
	}

	return false
}

// AddIfNotContains add item if not already in collection.
// Function returns true or false according to add result.
func (s *StringArray) AddIfNotContains(item string) bool {
	if s.Contains(item) {
		// Item not added
		return false
	}
	*s = append(*s, item)

	// Item added
	return true
}

// Remove item from collection.
// Function returns true or false according to removal result.
func (s *StringArray) Remove(item string) bool {
	idx := -1
	for i, v := range *s {
		if strings.EqualFold(item, v) {
			idx = i
			break
		}
	}
	if idx < 0 {
		// Item not removed
		return false
	}
	*s = append((*s)[:idx], (*s)[idx+1:]...)

	// Item removed
	return true
}

// HasOneOf returns true when one of provided items is found in array.
func (s *StringArray) HasOneOf(items ...string) bool {
	for _, item := range items {
		if s.Contains(item) {
			return true
		}
	}

	return false
}
